from playhouse.migrate import *
from playhouse.shortcuts import ReconnectMixin
from playhouse.sqlite_ext import SqliteExtDatabase

import modules.roxy_wi_tools as roxy_wi_tools

get_config = roxy_wi_tools.GetConfigVar()
mysql_enable = get_config.get_config_var('mysql', 'enable')

class ReconnectMySQLDatabase(ReconnectMixin, MySQLDatabase):
    pass

def connect(get_migrator=None):
    if mysql_enable == '1':
        mysql_user = get_config.get_config_var('mysql', 'mysql_user')
        mysql_password = get_config.get_config_var('mysql', 'mysql_password')
        mysql_db = get_config.get_config_var('mysql', 'mysql_db')
        mysql_host = get_config.get_config_var('mysql', 'mysql_host')
        mysql_port = get_config.get_config_var('mysql', 'mysql_port')
        conn = ReconnectMySQLDatabase(mysql_db, user=mysql_user, password=mysql_password, host=mysql_host, port=int(mysql_port))
        migrator = MySQLMigrator(conn)
    else:
        db = "/var/lib/roxy-wi/roxy-wi.db"
        conn = SqliteExtDatabase(db, pragmas=(
            ('cache_size', -1024 * 64),  # 64MB page-cache.
            ('journal_mode', 'wal'),
            ('foreign_keys', 1)
        ))
        migrator = SqliteMigrator(conn)
    if get_migrator:
        return migrator
    else:
        return conn

conn = connect()
migrator = connect(get_migrator=1)

print('==== Updating to version 8 ====')

try:
    migrate(
        migrator.rename_column('telegram', 'groups', 'group_id'),
    )
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")

try:
    migrate(migrator.rename_column('slack', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('mattermost', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('pd', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('udp_balancers', 'desc', 'description'))
except Exception as e:
    if e.args[0] == 'no such column: "desc"' or str(e) == '(1060, no such column: "desc")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('ha_clusters', 'desc', 'description'))
except Exception as e:
    if e.args[0] == 'no such column: "desc"' or str(e) == '(1060, no such column: "desc")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('cred', 'enable', 'key_enabled'))
except Exception as e:
    if e.args[0] == 'no such column: "cred"' or str(e) == '(1060, no such column: "cred")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('cred', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'desc', 'description'))
except Exception as e:
    if e.args[0] == 'no such column: "desc"' or str(e) == '(1060, no such column: "desc")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'active', 'haproxy_active'))
except Exception as e:
    if e.args[0] == 'no such column: "active"' or str(e) == '(1060, no such column: "acitve")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'metrics', 'haproxy_metrics'))
except Exception as e:
    if e.args[0] == 'no such column: "metrics"' or str(e) == '(1060, no such column: "metrics")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'alert', 'haproxy_alert'))
except Exception as e:
    if e.args[0] == 'no such column: "alert"' or str(e) == '(1060, no such column: "alert")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'cred', 'cred_id'))
except Exception as e:
    if e.args[0] == 'no such column: "cred"' or str(e) == '(1060, no such column: "cred")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'enable', 'enabled'))
except Exception as e:
    if e.args[0] == 'no such column: "enable"' or str(e) == '(1060, no such column: "enable")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('servers', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('user', 'activeuser', 'enabled'))
except Exception as e:
    if e.args[0] == 'no such column: "activeuser"' or str(e) == '(1060, no such column: "activeuser")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('user', 'groups', 'group_id'))
except Exception as e:
    if e.args[0] == 'no such column: "groups"' or str(e) == '(1060, no such column: "groups")':
        print("Updating... DB has been updated to version 8")
try:
    migrate(migrator.rename_column('user', 'role', 'role_id'))
except Exception as e:
    if e.args[0] == 'no such column: "role"' or str(e) == '(1060, no such column: "role")':
        print("Updating... DB has been updated to version 8")


print('==== Updating finished ====')
